@@ -8,7 +8,7 @@ use std::{
 };
 
 use anyhow::Result;
-use clap::Clap;
+use clap::Parser;
 use gitoxide_core as core;
 use gitoxide_core::pack::verify;
 
